from ..broker import Broker


class DeviceServiceBroker(Broker):
    controller = "device_services"

    def show(self, **kwargs):
        """Shows the details for the specified device service.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceServiceID: The internal NetMRI identifier for the Service.
             :type DeviceServiceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device service methods. The listed methods will be called on each device service returned and included in the output. Available methods are: device_cfg_context, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_cfg_context, data_source, device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_service: The device service identified by the specified DeviceServiceID.
             :rtype device_service: DeviceService

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available device services. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device that holds this service.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceServiceID: The internal NetMRI identifier for the Service.
             :type DeviceServiceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcName: Name of this service.
             :type SvcName: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device services as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device service methods. The listed methods will be called on each device service returned and included in the output. Available methods are: device_cfg_context, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_cfg_context, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceServiceID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceServiceID. Valid values are DeviceServiceID, DeviceID, DeviceCfgContextID, DataSourceID, SvcFirstSeenTime, SvcStartTime, SvcEndTime, SvcTimestamp, SvcChangedCols, SvcName, SvcUseCount, SvcArtificialInd, SvcType, SvcConfigText, SvcProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceService. Valid values are DeviceServiceID, DeviceID, DeviceCfgContextID, DataSourceID, SvcFirstSeenTime, SvcStartTime, SvcEndTime, SvcTimestamp, SvcChangedCols, SvcName, SvcUseCount, SvcArtificialInd, SvcType, SvcConfigText, SvcProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_services: An array of the DeviceService objects that match the specified input criteria.
             :rtype device_services: Array of DeviceService

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available device services matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceCfgContextID: The internal NetMRI identifier of the Configuration context of declaration of this service.
             :type DeviceCfgContextID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device that holds this service.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceServiceID: The internal NetMRI identifier for the Service.
             :type DeviceServiceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcArtificialInd: Flag indicating this service does not exist in the device configuration.
             :type SvcArtificialInd: Array of Boolean

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type SvcChangedCols: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcConfigText: Original text of the definition of this service in the device configuration.
             :type SvcConfigText: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcEndTime: The ending effective time of this record, or empty if still in effect.
             :type SvcEndTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcFirstSeenTime: The timestamp of when NetMRI first discovered this service.
             :type SvcFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcName: Name of this service.
             :type SvcName: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcProvisionData: Internal data - do not modify, may change without warning.
             :type SvcProvisionData: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcStartTime: The starting effective time of this record.
             :type SvcStartTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcTimestamp: The date and time this record was collected or calculated.
             :type SvcTimestamp: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcType: A string indicating the kind of service that element is describing. One of : service, container, protLst, prtLst, protPrtLst.
             :type SvcType: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SvcUseCount: Total count of usage of this service by other elements of the configuration (rules, other services).
             :type SvcUseCount: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device services as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device service methods. The listed methods will be called on each device service returned and included in the output. Available methods are: device_cfg_context, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_cfg_context, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceServiceID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceServiceID. Valid values are DeviceServiceID, DeviceID, DeviceCfgContextID, DataSourceID, SvcFirstSeenTime, SvcStartTime, SvcEndTime, SvcTimestamp, SvcChangedCols, SvcName, SvcUseCount, SvcArtificialInd, SvcType, SvcConfigText, SvcProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceService. Valid values are DeviceServiceID, DeviceID, DeviceCfgContextID, DataSourceID, SvcFirstSeenTime, SvcStartTime, SvcEndTime, SvcTimestamp, SvcChangedCols, SvcName, SvcUseCount, SvcArtificialInd, SvcType, SvcConfigText, SvcProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device services, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceCfgContextID, DeviceID, DeviceServiceID, SvcArtificialInd, SvcChangedCols, SvcConfigText, SvcEndTime, SvcFirstSeenTime, SvcName, SvcProvisionData, SvcStartTime, SvcTimestamp, SvcType, SvcUseCount.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_services: An array of the DeviceService objects that match the specified input criteria.
             :rtype device_services: Array of DeviceService

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device services matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceCfgContextID, DeviceID, DeviceServiceID, SvcArtificialInd, SvcChangedCols, SvcConfigText, SvcEndTime, SvcFirstSeenTime, SvcName, SvcProvisionData, SvcStartTime, SvcTimestamp, SvcType, SvcUseCount.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceCfgContextID: The operator to apply to the field DeviceCfgContextID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceCfgContextID: The internal NetMRI identifier of the Configuration context of declaration of this service. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceCfgContextID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceCfgContextID: If op_DeviceCfgContextID is specified, the field named in this input will be compared to the value in DeviceCfgContextID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceCfgContextID must be specified if op_DeviceCfgContextID is specified.
             :type val_f_DeviceCfgContextID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceCfgContextID: If op_DeviceCfgContextID is specified, this value will be compared to the value in DeviceCfgContextID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceCfgContextID must be specified if op_DeviceCfgContextID is specified.
             :type val_c_DeviceCfgContextID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device that holds this service. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceServiceID: The operator to apply to the field DeviceServiceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceServiceID: The internal NetMRI identifier for the Service. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceServiceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceServiceID: If op_DeviceServiceID is specified, the field named in this input will be compared to the value in DeviceServiceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceServiceID must be specified if op_DeviceServiceID is specified.
             :type val_f_DeviceServiceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceServiceID: If op_DeviceServiceID is specified, this value will be compared to the value in DeviceServiceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceServiceID must be specified if op_DeviceServiceID is specified.
             :type val_c_DeviceServiceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcArtificialInd: The operator to apply to the field SvcArtificialInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcArtificialInd: Flag indicating this service does not exist in the device configuration. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcArtificialInd: If op_SvcArtificialInd is specified, the field named in this input will be compared to the value in SvcArtificialInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcArtificialInd must be specified if op_SvcArtificialInd is specified.
             :type val_f_SvcArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcArtificialInd: If op_SvcArtificialInd is specified, this value will be compared to the value in SvcArtificialInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcArtificialInd must be specified if op_SvcArtificialInd is specified.
             :type val_c_SvcArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcChangedCols: The operator to apply to the field SvcChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcChangedCols: If op_SvcChangedCols is specified, the field named in this input will be compared to the value in SvcChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcChangedCols must be specified if op_SvcChangedCols is specified.
             :type val_f_SvcChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcChangedCols: If op_SvcChangedCols is specified, this value will be compared to the value in SvcChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcChangedCols must be specified if op_SvcChangedCols is specified.
             :type val_c_SvcChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcConfigText: The operator to apply to the field SvcConfigText. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcConfigText: Original text of the definition of this service in the device configuration. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcConfigText: If op_SvcConfigText is specified, the field named in this input will be compared to the value in SvcConfigText using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcConfigText must be specified if op_SvcConfigText is specified.
             :type val_f_SvcConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcConfigText: If op_SvcConfigText is specified, this value will be compared to the value in SvcConfigText using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcConfigText must be specified if op_SvcConfigText is specified.
             :type val_c_SvcConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcEndTime: The operator to apply to the field SvcEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcEndTime: If op_SvcEndTime is specified, the field named in this input will be compared to the value in SvcEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcEndTime must be specified if op_SvcEndTime is specified.
             :type val_f_SvcEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcEndTime: If op_SvcEndTime is specified, this value will be compared to the value in SvcEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcEndTime must be specified if op_SvcEndTime is specified.
             :type val_c_SvcEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcFirstSeenTime: The operator to apply to the field SvcFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcFirstSeenTime: The timestamp of when NetMRI first discovered this service. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcFirstSeenTime: If op_SvcFirstSeenTime is specified, the field named in this input will be compared to the value in SvcFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcFirstSeenTime must be specified if op_SvcFirstSeenTime is specified.
             :type val_f_SvcFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcFirstSeenTime: If op_SvcFirstSeenTime is specified, this value will be compared to the value in SvcFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcFirstSeenTime must be specified if op_SvcFirstSeenTime is specified.
             :type val_c_SvcFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcName: The operator to apply to the field SvcName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcName: Name of this service. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcName: If op_SvcName is specified, the field named in this input will be compared to the value in SvcName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcName must be specified if op_SvcName is specified.
             :type val_f_SvcName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcName: If op_SvcName is specified, this value will be compared to the value in SvcName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcName must be specified if op_SvcName is specified.
             :type val_c_SvcName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcProvisionData: The operator to apply to the field SvcProvisionData. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcProvisionData: Internal data - do not modify, may change without warning. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcProvisionData: If op_SvcProvisionData is specified, the field named in this input will be compared to the value in SvcProvisionData using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcProvisionData must be specified if op_SvcProvisionData is specified.
             :type val_f_SvcProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcProvisionData: If op_SvcProvisionData is specified, this value will be compared to the value in SvcProvisionData using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcProvisionData must be specified if op_SvcProvisionData is specified.
             :type val_c_SvcProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcStartTime: The operator to apply to the field SvcStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcStartTime: If op_SvcStartTime is specified, the field named in this input will be compared to the value in SvcStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcStartTime must be specified if op_SvcStartTime is specified.
             :type val_f_SvcStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcStartTime: If op_SvcStartTime is specified, this value will be compared to the value in SvcStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcStartTime must be specified if op_SvcStartTime is specified.
             :type val_c_SvcStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcTimestamp: The operator to apply to the field SvcTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcTimestamp: If op_SvcTimestamp is specified, the field named in this input will be compared to the value in SvcTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcTimestamp must be specified if op_SvcTimestamp is specified.
             :type val_f_SvcTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcTimestamp: If op_SvcTimestamp is specified, this value will be compared to the value in SvcTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcTimestamp must be specified if op_SvcTimestamp is specified.
             :type val_c_SvcTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcType: The operator to apply to the field SvcType. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcType: A string indicating the kind of service that element is describing. One of : service, container, protLst, prtLst, protPrtLst. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcType: If op_SvcType is specified, the field named in this input will be compared to the value in SvcType using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcType must be specified if op_SvcType is specified.
             :type val_f_SvcType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcType: If op_SvcType is specified, this value will be compared to the value in SvcType using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcType must be specified if op_SvcType is specified.
             :type val_c_SvcType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SvcUseCount: The operator to apply to the field SvcUseCount. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SvcUseCount: Total count of usage of this service by other elements of the configuration (rules, other services). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SvcUseCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SvcUseCount: If op_SvcUseCount is specified, the field named in this input will be compared to the value in SvcUseCount using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SvcUseCount must be specified if op_SvcUseCount is specified.
             :type val_f_SvcUseCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SvcUseCount: If op_SvcUseCount is specified, this value will be compared to the value in SvcUseCount using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SvcUseCount must be specified if op_SvcUseCount is specified.
             :type val_c_SvcUseCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device services as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device service methods. The listed methods will be called on each device service returned and included in the output. Available methods are: device_cfg_context, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_cfg_context, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceServiceID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceServiceID. Valid values are DeviceServiceID, DeviceID, DeviceCfgContextID, DataSourceID, SvcFirstSeenTime, SvcStartTime, SvcEndTime, SvcTimestamp, SvcChangedCols, SvcName, SvcUseCount, SvcArtificialInd, SvcType, SvcConfigText, SvcProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceService. Valid values are DeviceServiceID, DeviceID, DeviceCfgContextID, DataSourceID, SvcFirstSeenTime, SvcStartTime, SvcEndTime, SvcTimestamp, SvcChangedCols, SvcName, SvcUseCount, SvcArtificialInd, SvcType, SvcConfigText, SvcProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_services: An array of the DeviceService objects that match the specified input criteria.
             :rtype device_services: Array of DeviceService

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def device_cfg_context(self, **kwargs):
        """The Configuration context of declaration of this service.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceServiceID: The internal NetMRI identifier for the Service.
             :type DeviceServiceID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The Configuration context of declaration of this service.
             :rtype : DeviceCfgContext

            """

        return self.api_request(self._get_method_fullname("device_cfg_context"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceServiceID: The internal NetMRI identifier for the Service.
             :type DeviceServiceID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceServiceID: The internal NetMRI identifier for the Service.
             :type DeviceServiceID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)

    def to_detail(self, **kwargs):
        """Returns the deail for an service.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: None
             :type id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param view: 0=tostring, 1=tooltip, 2-popup, 3=tostring/field, 4=tooltip/field, 5=popup/field
             :type view: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return detail: None
             :rtype detail: String

            """

        return self.api_request(self._get_method_fullname("to_detail"), kwargs)



import re
from pydoc import safeimport


def locate(path, forceload=False):
    """Locate an object by name or dotted path, importing as necessary."""
    parts = [part for part in path.split('.') if part]
    module, n = None, 0
    while n < len(parts):
        nextmodule = safeimport('.'.join(parts[:n + 1]), forceload)
        if nextmodule:
            module, n = nextmodule, n + 1
        else:
            break
    for part in parts[n:]:
        try:
            module = getattr(module, part)
        except AttributeError:
            raise RuntimeError('Object: {} not found'.format(path))
    return module


def to_snake(name):
    s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
    return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()


def check_api_availability(f):
    def wrapper(self, *args):
        func_name = f.__name__
        if getattr(self.broker, func_name, None):
            return f(self, *args)
        else:
            raise RuntimeError(
                "Api call not available for current API version: {}".format(self.broker.client.api_version))

    return wrapper


def to_underscore_notation(name):
    name = str(name)
    if "." not in name:
        return "v{}_0_0".format(name)
    elif name.count(".") == 1:
        return "v{}_0".format(name.replace(".", "_"))
    else:
        return "v{}".format(name.replace(".", "_"))



from ..broker import Broker


class DeviceObjectObjectBroker(Broker):
    controller = "device_object_objects"

    def show(self, **kwargs):
        """Shows the details for the specified device object object.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects.
             :type DeviceObjectObjectID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device object object methods. The listed methods will be called on each device object object returned and included in the output. Available methods are: parent_device_object, child_device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: parent_device_object, child_device_object, data_source, device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_object_object: The device object object identified by the specified DeviceObjectObjectID.
             :rtype device_object_object: DeviceObjectObject

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available device object objects. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which belongs this network objects.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects.
             :type DeviceObjectObjectID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device object objects as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device object object methods. The listed methods will be called on each device object object returned and included in the output. Available methods are: parent_device_object, child_device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: parent_device_object, child_device_object, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceObjectObjectID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceObjectObjectID. Valid values are DeviceObjectObjectID, DeviceID, DataSourceID, ParentDeviceObjectID, ChildDeviceObjectID, OoFirstSeenTime, OoStartTime, OoEndTime, OoTimestamp, OoChangedCols, OoProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceObjectObject. Valid values are DeviceObjectObjectID, DeviceID, DataSourceID, ParentDeviceObjectID, ChildDeviceObjectID, OoFirstSeenTime, OoStartTime, OoEndTime, OoTimestamp, OoChangedCols, OoProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_object_objects: An array of the DeviceObjectObject objects that match the specified input criteria.
             :rtype device_object_objects: Array of DeviceObjectObject

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available device object objects matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ChildDeviceObjectID: The internal NetMRI identifier of the child network object (the used service).
             :type ChildDeviceObjectID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which belongs this network objects.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects.
             :type DeviceObjectObjectID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param OoChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type OoChangedCols: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param OoEndTime: The ending effective time of this record, or empty if still in effect.
             :type OoEndTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param OoFirstSeenTime: The timestamp of when NetMRI saw for the first time this relationship.
             :type OoFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param OoProvisionData: Internal data - do not modify, may change without warning.
             :type OoProvisionData: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param OoStartTime: The starting effective time of this record.
             :type OoStartTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param OoTimestamp: The date and time this record was collected or calculated.
             :type OoTimestamp: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ParentDeviceObjectID: The internal NetMRI identifier of the parent network object (the user).
             :type ParentDeviceObjectID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device object objects as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device object object methods. The listed methods will be called on each device object object returned and included in the output. Available methods are: parent_device_object, child_device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: parent_device_object, child_device_object, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceObjectObjectID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceObjectObjectID. Valid values are DeviceObjectObjectID, DeviceID, DataSourceID, ParentDeviceObjectID, ChildDeviceObjectID, OoFirstSeenTime, OoStartTime, OoEndTime, OoTimestamp, OoChangedCols, OoProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceObjectObject. Valid values are DeviceObjectObjectID, DeviceID, DataSourceID, ParentDeviceObjectID, ChildDeviceObjectID, OoFirstSeenTime, OoStartTime, OoEndTime, OoTimestamp, OoChangedCols, OoProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device object objects, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: ChildDeviceObjectID, DataSourceID, DeviceID, DeviceObjectObjectID, OoChangedCols, OoEndTime, OoFirstSeenTime, OoProvisionData, OoStartTime, OoTimestamp, ParentDeviceObjectID.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_object_objects: An array of the DeviceObjectObject objects that match the specified input criteria.
             :rtype device_object_objects: Array of DeviceObjectObject

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device object objects matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: ChildDeviceObjectID, DataSourceID, DeviceID, DeviceObjectObjectID, OoChangedCols, OoEndTime, OoFirstSeenTime, OoProvisionData, OoStartTime, OoTimestamp, ParentDeviceObjectID.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ChildDeviceObjectID: The operator to apply to the field ChildDeviceObjectID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ChildDeviceObjectID: The internal NetMRI identifier of the child network object (the used service). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ChildDeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ChildDeviceObjectID: If op_ChildDeviceObjectID is specified, the field named in this input will be compared to the value in ChildDeviceObjectID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ChildDeviceObjectID must be specified if op_ChildDeviceObjectID is specified.
             :type val_f_ChildDeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ChildDeviceObjectID: If op_ChildDeviceObjectID is specified, this value will be compared to the value in ChildDeviceObjectID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ChildDeviceObjectID must be specified if op_ChildDeviceObjectID is specified.
             :type val_c_ChildDeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device to which belongs this network objects. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceObjectObjectID: The operator to apply to the field DeviceObjectObjectID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceObjectObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceObjectObjectID: If op_DeviceObjectObjectID is specified, the field named in this input will be compared to the value in DeviceObjectObjectID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceObjectObjectID must be specified if op_DeviceObjectObjectID is specified.
             :type val_f_DeviceObjectObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceObjectObjectID: If op_DeviceObjectObjectID is specified, this value will be compared to the value in DeviceObjectObjectID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceObjectObjectID must be specified if op_DeviceObjectObjectID is specified.
             :type val_c_DeviceObjectObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_OoChangedCols: The operator to apply to the field OoChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. OoChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_OoChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_OoChangedCols: If op_OoChangedCols is specified, the field named in this input will be compared to the value in OoChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_OoChangedCols must be specified if op_OoChangedCols is specified.
             :type val_f_OoChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_OoChangedCols: If op_OoChangedCols is specified, this value will be compared to the value in OoChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_OoChangedCols must be specified if op_OoChangedCols is specified.
             :type val_c_OoChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_OoEndTime: The operator to apply to the field OoEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. OoEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_OoEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_OoEndTime: If op_OoEndTime is specified, the field named in this input will be compared to the value in OoEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_OoEndTime must be specified if op_OoEndTime is specified.
             :type val_f_OoEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_OoEndTime: If op_OoEndTime is specified, this value will be compared to the value in OoEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_OoEndTime must be specified if op_OoEndTime is specified.
             :type val_c_OoEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_OoFirstSeenTime: The operator to apply to the field OoFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. OoFirstSeenTime: The timestamp of when NetMRI saw for the first time this relationship. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_OoFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_OoFirstSeenTime: If op_OoFirstSeenTime is specified, the field named in this input will be compared to the value in OoFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_OoFirstSeenTime must be specified if op_OoFirstSeenTime is specified.
             :type val_f_OoFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_OoFirstSeenTime: If op_OoFirstSeenTime is specified, this value will be compared to the value in OoFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_OoFirstSeenTime must be specified if op_OoFirstSeenTime is specified.
             :type val_c_OoFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_OoProvisionData: The operator to apply to the field OoProvisionData. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. OoProvisionData: Internal data - do not modify, may change without warning. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_OoProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_OoProvisionData: If op_OoProvisionData is specified, the field named in this input will be compared to the value in OoProvisionData using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_OoProvisionData must be specified if op_OoProvisionData is specified.
             :type val_f_OoProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_OoProvisionData: If op_OoProvisionData is specified, this value will be compared to the value in OoProvisionData using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_OoProvisionData must be specified if op_OoProvisionData is specified.
             :type val_c_OoProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_OoStartTime: The operator to apply to the field OoStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. OoStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_OoStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_OoStartTime: If op_OoStartTime is specified, the field named in this input will be compared to the value in OoStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_OoStartTime must be specified if op_OoStartTime is specified.
             :type val_f_OoStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_OoStartTime: If op_OoStartTime is specified, this value will be compared to the value in OoStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_OoStartTime must be specified if op_OoStartTime is specified.
             :type val_c_OoStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_OoTimestamp: The operator to apply to the field OoTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. OoTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_OoTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_OoTimestamp: If op_OoTimestamp is specified, the field named in this input will be compared to the value in OoTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_OoTimestamp must be specified if op_OoTimestamp is specified.
             :type val_f_OoTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_OoTimestamp: If op_OoTimestamp is specified, this value will be compared to the value in OoTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_OoTimestamp must be specified if op_OoTimestamp is specified.
             :type val_c_OoTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ParentDeviceObjectID: The operator to apply to the field ParentDeviceObjectID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ParentDeviceObjectID: The internal NetMRI identifier of the parent network object (the user). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ParentDeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ParentDeviceObjectID: If op_ParentDeviceObjectID is specified, the field named in this input will be compared to the value in ParentDeviceObjectID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ParentDeviceObjectID must be specified if op_ParentDeviceObjectID is specified.
             :type val_f_ParentDeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ParentDeviceObjectID: If op_ParentDeviceObjectID is specified, this value will be compared to the value in ParentDeviceObjectID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ParentDeviceObjectID must be specified if op_ParentDeviceObjectID is specified.
             :type val_c_ParentDeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device object objects as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device object object methods. The listed methods will be called on each device object object returned and included in the output. Available methods are: parent_device_object, child_device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: parent_device_object, child_device_object, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceObjectObjectID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceObjectObjectID. Valid values are DeviceObjectObjectID, DeviceID, DataSourceID, ParentDeviceObjectID, ChildDeviceObjectID, OoFirstSeenTime, OoStartTime, OoEndTime, OoTimestamp, OoChangedCols, OoProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceObjectObject. Valid values are DeviceObjectObjectID, DeviceID, DataSourceID, ParentDeviceObjectID, ChildDeviceObjectID, OoFirstSeenTime, OoStartTime, OoEndTime, OoTimestamp, OoChangedCols, OoProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_object_objects: An array of the DeviceObjectObject objects that match the specified input criteria.
             :rtype device_object_objects: Array of DeviceObjectObject

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def parent_device_object(self, **kwargs):
        """The parent network object of this relationship.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects.
             :type DeviceObjectObjectID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The parent network object of this relationship.
             :rtype : DeviceObject

            """

        return self.api_request(self._get_method_fullname("parent_device_object"), kwargs)

    def child_device_object(self, **kwargs):
        """The child network object of this relationship.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects.
             :type DeviceObjectObjectID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The child network object of this relationship.
             :rtype : DeviceObject

            """

        return self.api_request(self._get_method_fullname("child_device_object"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects.
             :type DeviceObjectObjectID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceObjectObjectID: The internal NetMRI identifier of this usage relationship between network objects.
             :type DeviceObjectObjectID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)



from ..broker import Broker


class IfVlanBroker(Broker):
    controller = "if_vlans"

    def show(self, **kwargs):
        """Shows the details for the specified if vlan.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if vlan methods. The listed methods will be called on each if vlan returned and included in the output. Available methods are: meta, data_source, device, interface, vlan, vlan_member, infradevice.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: meta, data_source, device, interface, vlan, vlan_member.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_vlan: The if vlan identified by the specified IfVlanID.
             :rtype if_vlan: IfVlan

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available if vlans. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of the device to which the interface belongs.
             :type DeviceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of the device to which the interface belongs.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the interface participating in the VLAN.
             :type InterfaceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the interface participating in the VLAN.
             :type InterfaceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param VlanID: The internal NetMRI identifier of the VLAN.
             :type VlanID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VlanID: The internal NetMRI identifier of the VLAN.
             :type VlanID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the if vlans as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if vlan methods. The listed methods will be called on each if vlan returned and included in the output. Available methods are: meta, data_source, device, interface, vlan, vlan_member, infradevice.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: meta, data_source, device, interface, vlan, vlan_member.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IfVlanID

             :param sort: The data field(s) to use for sorting the output. Default is IfVlanID. Valid values are IfVlanID, DataSourceID, DeviceID, InterfaceID, VlanID, ifVlanStartTime, ifVlanEndTime, ifVlanChangedCols, ifVlanTimestamp, ifVlanSource, VlanMemberID, VlanInterfaceInd, VlanExtensionInd, StpPortState, StpPortDesignatedBridge.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IfVlan. Valid values are IfVlanID, DataSourceID, DeviceID, InterfaceID, VlanID, ifVlanStartTime, ifVlanEndTime, ifVlanChangedCols, ifVlanTimestamp, ifVlanSource, VlanMemberID, VlanInterfaceInd, VlanExtensionInd, StpPortState, StpPortDesignatedBridge. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_vlans: An array of the IfVlan objects that match the specified input criteria.
             :rtype if_vlans: Array of IfVlan

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available if vlans matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of the device to which the interface belongs.
             :type DeviceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier of the device to which the interface belongs.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the interface participating in the VLAN.
             :type InterfaceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the interface participating in the VLAN.
             :type InterfaceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param StpPortDesignatedBridge: The Spanning Tree Protocol designated bridge address of this interface for this VLAN.
             :type StpPortDesignatedBridge: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param StpPortDesignatedBridge: The Spanning Tree Protocol designated bridge address of this interface for this VLAN.
             :type StpPortDesignatedBridge: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param StpPortState: The Spanning Tree Protocol state of this interface for this VLAN.
             :type StpPortState: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param StpPortState: The Spanning Tree Protocol state of this interface for this VLAN.
             :type StpPortState: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param VlanExtensionInd: A flag indicating if this record represents an interface attached to an access port rather than on a participating bridge.
             :type VlanExtensionInd: Boolean

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VlanExtensionInd: A flag indicating if this record represents an interface attached to an access port rather than on a participating bridge.
             :type VlanExtensionInd: Array of Boolean

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param VlanID: The internal NetMRI identifier of the VLAN.
             :type VlanID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VlanID: The internal NetMRI identifier of the VLAN.
             :type VlanID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param VlanInterfaceInd: A flag indicating if this record represents the SVI for the VLAN on this device.
             :type VlanInterfaceInd: Boolean

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VlanInterfaceInd: A flag indicating if this record represents the SVI for the VLAN on this device.
             :type VlanInterfaceInd: Array of Boolean

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param VlanMemberID: The internal NetMRI identifier for the VlanMember record of the device to which the interface belongs, for this VLAN.
             :type VlanMemberID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param VlanMemberID: The internal NetMRI identifier for the VlanMember record of the device to which the interface belongs, for this VLAN.
             :type VlanMemberID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type ifVlanChangedCols: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type ifVlanChangedCols: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type ifVlanEndTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type ifVlanEndTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanSource: Internal tracking information for NetMRI algorithms.
             :type ifVlanSource: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanSource: Internal tracking information for NetMRI algorithms.
             :type ifVlanSource: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanStartTime: The starting effective time of this revision of the record.
             :type ifVlanStartTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanStartTime: The starting effective time of this revision of the record.
             :type ifVlanStartTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanTimestamp: The date and time this record was collected or calculated.
             :type ifVlanTimestamp: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifVlanTimestamp: The date and time this record was collected or calculated.
             :type ifVlanTimestamp: Array of DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the if vlans as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if vlan methods. The listed methods will be called on each if vlan returned and included in the output. Available methods are: meta, data_source, device, interface, vlan, vlan_member, infradevice.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: meta, data_source, device, interface, vlan, vlan_member.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IfVlanID

             :param sort: The data field(s) to use for sorting the output. Default is IfVlanID. Valid values are IfVlanID, DataSourceID, DeviceID, InterfaceID, VlanID, ifVlanStartTime, ifVlanEndTime, ifVlanChangedCols, ifVlanTimestamp, ifVlanSource, VlanMemberID, VlanInterfaceInd, VlanExtensionInd, StpPortState, StpPortDesignatedBridge.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IfVlan. Valid values are IfVlanID, DataSourceID, DeviceID, InterfaceID, VlanID, ifVlanStartTime, ifVlanEndTime, ifVlanChangedCols, ifVlanTimestamp, ifVlanSource, VlanMemberID, VlanInterfaceInd, VlanExtensionInd, StpPortState, StpPortDesignatedBridge. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against if vlans, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceID, IfVlanID, InterfaceID, StpPortDesignatedBridge, StpPortState, VlanExtensionInd, VlanID, VlanInterfaceInd, VlanMemberID, ifVlanChangedCols, ifVlanEndTime, ifVlanSource, ifVlanStartTime, ifVlanTimestamp.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_vlans: An array of the IfVlan objects that match the specified input criteria.
             :rtype if_vlans: Array of IfVlan

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available if vlans matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceID, IfVlanID, InterfaceID, StpPortDesignatedBridge, StpPortState, VlanExtensionInd, VlanID, VlanInterfaceInd, VlanMemberID, ifVlanChangedCols, ifVlanEndTime, ifVlanSource, ifVlanStartTime, ifVlanTimestamp.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier of the device to which the interface belongs. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IfVlanID: The operator to apply to the field IfVlanID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IfVlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IfVlanID: If op_IfVlanID is specified, the field named in this input will be compared to the value in IfVlanID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IfVlanID must be specified if op_IfVlanID is specified.
             :type val_f_IfVlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IfVlanID: If op_IfVlanID is specified, this value will be compared to the value in IfVlanID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IfVlanID must be specified if op_IfVlanID is specified.
             :type val_c_IfVlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_InterfaceID: The operator to apply to the field InterfaceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. InterfaceID: The internal NetMRI identifier of the interface participating in the VLAN. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_InterfaceID: If op_InterfaceID is specified, the field named in this input will be compared to the value in InterfaceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_f_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_InterfaceID: If op_InterfaceID is specified, this value will be compared to the value in InterfaceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_c_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_StpPortDesignatedBridge: The operator to apply to the field StpPortDesignatedBridge. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. StpPortDesignatedBridge: The Spanning Tree Protocol designated bridge address of this interface for this VLAN. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_StpPortDesignatedBridge: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_StpPortDesignatedBridge: If op_StpPortDesignatedBridge is specified, the field named in this input will be compared to the value in StpPortDesignatedBridge using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_StpPortDesignatedBridge must be specified if op_StpPortDesignatedBridge is specified.
             :type val_f_StpPortDesignatedBridge: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_StpPortDesignatedBridge: If op_StpPortDesignatedBridge is specified, this value will be compared to the value in StpPortDesignatedBridge using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_StpPortDesignatedBridge must be specified if op_StpPortDesignatedBridge is specified.
             :type val_c_StpPortDesignatedBridge: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_StpPortState: The operator to apply to the field StpPortState. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. StpPortState: The Spanning Tree Protocol state of this interface for this VLAN. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_StpPortState: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_StpPortState: If op_StpPortState is specified, the field named in this input will be compared to the value in StpPortState using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_StpPortState must be specified if op_StpPortState is specified.
             :type val_f_StpPortState: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_StpPortState: If op_StpPortState is specified, this value will be compared to the value in StpPortState using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_StpPortState must be specified if op_StpPortState is specified.
             :type val_c_StpPortState: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VlanExtensionInd: The operator to apply to the field VlanExtensionInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VlanExtensionInd: A flag indicating if this record represents an interface attached to an access port rather than on a participating bridge. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VlanExtensionInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VlanExtensionInd: If op_VlanExtensionInd is specified, the field named in this input will be compared to the value in VlanExtensionInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VlanExtensionInd must be specified if op_VlanExtensionInd is specified.
             :type val_f_VlanExtensionInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VlanExtensionInd: If op_VlanExtensionInd is specified, this value will be compared to the value in VlanExtensionInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VlanExtensionInd must be specified if op_VlanExtensionInd is specified.
             :type val_c_VlanExtensionInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VlanID: The operator to apply to the field VlanID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VlanID: The internal NetMRI identifier of the VLAN. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VlanID: If op_VlanID is specified, the field named in this input will be compared to the value in VlanID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VlanID must be specified if op_VlanID is specified.
             :type val_f_VlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VlanID: If op_VlanID is specified, this value will be compared to the value in VlanID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VlanID must be specified if op_VlanID is specified.
             :type val_c_VlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VlanInterfaceInd: The operator to apply to the field VlanInterfaceInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VlanInterfaceInd: A flag indicating if this record represents the SVI for the VLAN on this device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VlanInterfaceInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VlanInterfaceInd: If op_VlanInterfaceInd is specified, the field named in this input will be compared to the value in VlanInterfaceInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VlanInterfaceInd must be specified if op_VlanInterfaceInd is specified.
             :type val_f_VlanInterfaceInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VlanInterfaceInd: If op_VlanInterfaceInd is specified, this value will be compared to the value in VlanInterfaceInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VlanInterfaceInd must be specified if op_VlanInterfaceInd is specified.
             :type val_c_VlanInterfaceInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_VlanMemberID: The operator to apply to the field VlanMemberID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. VlanMemberID: The internal NetMRI identifier for the VlanMember record of the device to which the interface belongs, for this VLAN. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_VlanMemberID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_VlanMemberID: If op_VlanMemberID is specified, the field named in this input will be compared to the value in VlanMemberID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_VlanMemberID must be specified if op_VlanMemberID is specified.
             :type val_f_VlanMemberID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_VlanMemberID: If op_VlanMemberID is specified, this value will be compared to the value in VlanMemberID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_VlanMemberID must be specified if op_VlanMemberID is specified.
             :type val_c_VlanMemberID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifVlanChangedCols: The operator to apply to the field ifVlanChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifVlanChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifVlanChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifVlanChangedCols: If op_ifVlanChangedCols is specified, the field named in this input will be compared to the value in ifVlanChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifVlanChangedCols must be specified if op_ifVlanChangedCols is specified.
             :type val_f_ifVlanChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifVlanChangedCols: If op_ifVlanChangedCols is specified, this value will be compared to the value in ifVlanChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifVlanChangedCols must be specified if op_ifVlanChangedCols is specified.
             :type val_c_ifVlanChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifVlanEndTime: The operator to apply to the field ifVlanEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifVlanEndTime: The ending effective time of this revision of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifVlanEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifVlanEndTime: If op_ifVlanEndTime is specified, the field named in this input will be compared to the value in ifVlanEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifVlanEndTime must be specified if op_ifVlanEndTime is specified.
             :type val_f_ifVlanEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifVlanEndTime: If op_ifVlanEndTime is specified, this value will be compared to the value in ifVlanEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifVlanEndTime must be specified if op_ifVlanEndTime is specified.
             :type val_c_ifVlanEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifVlanSource: The operator to apply to the field ifVlanSource. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifVlanSource: Internal tracking information for NetMRI algorithms. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifVlanSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifVlanSource: If op_ifVlanSource is specified, the field named in this input will be compared to the value in ifVlanSource using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifVlanSource must be specified if op_ifVlanSource is specified.
             :type val_f_ifVlanSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifVlanSource: If op_ifVlanSource is specified, this value will be compared to the value in ifVlanSource using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifVlanSource must be specified if op_ifVlanSource is specified.
             :type val_c_ifVlanSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifVlanStartTime: The operator to apply to the field ifVlanStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifVlanStartTime: The starting effective time of this revision of the record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifVlanStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifVlanStartTime: If op_ifVlanStartTime is specified, the field named in this input will be compared to the value in ifVlanStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifVlanStartTime must be specified if op_ifVlanStartTime is specified.
             :type val_f_ifVlanStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifVlanStartTime: If op_ifVlanStartTime is specified, this value will be compared to the value in ifVlanStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifVlanStartTime must be specified if op_ifVlanStartTime is specified.
             :type val_c_ifVlanStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifVlanTimestamp: The operator to apply to the field ifVlanTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifVlanTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifVlanTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifVlanTimestamp: If op_ifVlanTimestamp is specified, the field named in this input will be compared to the value in ifVlanTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifVlanTimestamp must be specified if op_ifVlanTimestamp is specified.
             :type val_f_ifVlanTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifVlanTimestamp: If op_ifVlanTimestamp is specified, this value will be compared to the value in ifVlanTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifVlanTimestamp must be specified if op_ifVlanTimestamp is specified.
             :type val_c_ifVlanTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the if vlans as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if vlan methods. The listed methods will be called on each if vlan returned and included in the output. Available methods are: meta, data_source, device, interface, vlan, vlan_member, infradevice.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: meta, data_source, device, interface, vlan, vlan_member.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IfVlanID

             :param sort: The data field(s) to use for sorting the output. Default is IfVlanID. Valid values are IfVlanID, DataSourceID, DeviceID, InterfaceID, VlanID, ifVlanStartTime, ifVlanEndTime, ifVlanChangedCols, ifVlanTimestamp, ifVlanSource, VlanMemberID, VlanInterfaceInd, VlanExtensionInd, StpPortState, StpPortDesignatedBridge.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IfVlan. Valid values are IfVlanID, DataSourceID, DeviceID, InterfaceID, VlanID, ifVlanStartTime, ifVlanEndTime, ifVlanChangedCols, ifVlanTimestamp, ifVlanSource, VlanMemberID, VlanInterfaceInd, VlanExtensionInd, StpPortState, StpPortDesignatedBridge. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_vlans: An array of the IfVlan objects that match the specified input criteria.
             :rtype if_vlans: Array of IfVlan

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def data_source(self, **kwargs):
        """The NetMRI device that collected this record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The NetMRI device that collected this record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def interface(self, **kwargs):
        """The interface participating in the VLAN.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The interface participating in the VLAN.
             :rtype : Interface

            """

        return self.api_request(self._get_method_fullname("interface"), kwargs)

    def vlan(self, **kwargs):
        """The VLAN to which this interface VLAN membership belongs.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The VLAN to which this interface VLAN membership belongs.
             :rtype : Vlan

            """

        return self.api_request(self._get_method_fullname("vlan"), kwargs)

    def vlan_member(self, **kwargs):
        """The VLAN membership record of the device to which the interface belongs, for this VLAN.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The VLAN membership record of the device to which the interface belongs, for this VLAN.
             :rtype : VlanMember

            """

        return self.api_request(self._get_method_fullname("vlan_member"), kwargs)

    def infradevice(self, **kwargs):
        """The device to which the interface belongs.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device to which the interface belongs.
             :rtype : InfraDevice

            """

        return self.api_request(self._get_method_fullname("infradevice"), kwargs)

    def device(self, **kwargs):
        """The device to which the interface belongs.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfVlanID: The internal NetMRI identifier for the interface-in-VLAN record.
             :type IfVlanID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device to which the interface belongs.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)



from ..remote import RemoteModel


class SNMPCredentialRemote(RemoteModel):
    """
    The SNMP credentials to use when accessing devices.


    |  ``PasswordID:`` The internal NetMRI identifier for this credential.
    |  ``attribute type:`` number

    |  ``UnitID:`` The internal NetMRI identifier for the NetMRI collector on which the credential is configured.
    |  ``attribute type:`` number

    |  ``Protocol:`` The protocol for which to use this password.
    |  ``attribute type:`` string

    |  ``Type:`` Whether this is a read or read/write community.
    |  ``attribute type:`` string

    |  ``Origination:`` Indicates the source and use of the credential. 'User' indicates this is a user-entered password. 'Default' indicates that these are used by the Weak Password issue, and may be modified or removed on upgrade. 'Vendor' indicates a password tested in the Vendor Default Credential Guessing, and may be modified or removed on upgrade. 'Vendor (User Add)' is a user-added vendor default credential.
    |  ``attribute type:`` string

    |  ``HitCount:`` The number of successful uses of this credential.
    |  ``attribute type:`` number

    |  ``Vendor:`` The vendor devices against which to try this credential.
    |  ``attribute type:`` string

    |  ``SNMPAuthProto:`` The SNMPv3 authentication protocol to use with this credential.
    |  ``attribute type:`` string

    |  ``SNMPPrivProto:`` The SNMPv3 privacy protocol to use with this credential.
    |  ``attribute type:`` string

    |  ``Priority:`` The priority order in which to attempt this credential.
    |  ``attribute type:`` string

    |  ``PasswordSecure:`` (alias Password) Is the community string.
    |  ``attribute type:`` string

    |  ``SNMPAuthPWSecure:`` (alias SNMPAuthPW) Is the SNMPv3 authentication protocol password.
    |  ``attribute type:`` string

    |  ``SNMPPrivPWSecure:`` (alias SNMPPrivPW) Is the SNMPv3 privacy protocol password.
    |  ``attribute type:`` string

    |  ``SecureVersion:`` The encryption version of the username and passwords.
    |  ``attribute type:`` number

    |  ``CredentialGroupID:`` The unique identifier of the credential group.
    |  ``attribute type:`` number

    """

    properties = ("PasswordID",
                  "UnitID",
                  "Protocol",
                  "Type",
                  "Origination",
                  "HitCount",
                  "Vendor",
                  "SNMPAuthProto",
                  "SNMPPrivProto",
                  "Priority",
                  "PasswordSecure",
                  "SNMPAuthPWSecure",
                  "SNMPPrivPWSecure",
                  "SecureVersion",
                  "CredentialGroupID",
                  )



from ..remote import RemoteModel


class AttributeDocRemote(RemoteModel):
    """
    Documentation for model attributes.


    |  ``id:`` The internal NetMRI identifier for this attribute.
    |  ``attribute type:`` number

    |  ``attribute:`` Attribute name for this record.
    |  ``attribute type:`` string

    |  ``created_at:`` The date and time the record was initially created in NetMRI.
    |  ``attribute type:`` datetime

    |  ``updated_at:`` The date and time the record was last modified in NetMRI.
    |  ``attribute type:`` datetime

    |  ``default_column_ind:`` A flag indicating if this is default column/
    |  ``attribute type:`` bool

    |  ``default_sort_desc_ind:`` A flag indicating if default sort order is descending.
    |  ``attribute type:`` bool

    |  ``description:`` Attribute description
    |  ``attribute type:`` string

    |  ``gui_type:`` Data type used in GUI to handle the attribute.
    |  ``attribute type:`` string

    |  ``hidden_ind:`` A flag indicating if attribute is hidden
    |  ``attribute type:`` bool

    |  ``method_ind:`` A flag indicating if attribute is method
    |  ``attribute type:`` bool

    |  ``method_param_list:`` Parameter list for method
    |  ``attribute type:`` string

    |  ``model_doc_id:`` The internal NetMRI identifier of Model the attribute is assigned to.
    |  ``attribute type:`` number

    |  ``name:`` Human readable attribute name.
    |  ``attribute type:`` string

    |  ``return_model_doc_id:`` The internal NetMRI identifier of Model returned by method.
    |  ``attribute type:`` number

    """

    properties = ("id",
                  "attribute",
                  "created_at",
                  "updated_at",
                  "default_column_ind",
                  "default_sort_desc_ind",
                  "description",
                  "gui_type",
                  "hidden_ind",
                  "method_ind",
                  "method_param_list",
                  "model_doc_id",
                  "name",
                  "return_model_doc_id",
                  )



from ..remote import RemoteModel


class ScriptRemote(RemoteModel):
    """
    Includes all scripts currently available in this NetMRI installation.


    |  ``id:`` The internal NetMRI identifier for the script.
    |  ``attribute type:`` number

    |  ``name:`` The name of this script.
    |  ``attribute type:`` string

    |  ``module:`` Currently unused.
    |  ``attribute type:`` string

    |  ``visible:`` Indicates whether this script is visible on the user interface.
    |  ``attribute type:`` bool

    |  ``description:`` Describes the purpose, function and usage of this script.
    |  ``attribute type:`` string

    |  ``created_by:`` The user that initially imported the script into NetMRI.
    |  ``attribute type:`` string

    |  ``updated_by:`` The user that last modified this script.
    |  ``attribute type:`` string

    |  ``language:`` The scripting language used; currently the only supported language is CCS.
    |  ``attribute type:`` string

    |  ``risk_level:`` The user-specified risk level for the script. Possible levels are 1 (low), 2 (medium), and 3 (high). To run higher risk scripts, higher privileges are required.
    |  ``attribute type:`` number

    |  ``created_at:`` The date and time the script was initially imported into NetMRI.
    |  ``attribute type:`` datetime

    |  ``updated_at:`` The date and time the script was last modified.
    |  ``attribute type:`` datetime

    |  ``category:`` Currently unused.
    |  ``attribute type:`` string

    |  ``read_only:`` Read-only scripts are not user modifiable.
    |  ``attribute type:`` bool

    |  ``taskflow_create:`` Internal workflow name for job creation using this script.
    |  ``attribute type:`` string

    |  ``taskflow_edit:`` Internal workflow name for job edition using this script.
    |  ``attribute type:`` string

    |  ``taskflow_revert:`` Internal workflow name for job reversion using this script.
    |  ``attribute type:`` string

    |  ``target_mapping:`` Kind of mapping used for this script : 'device' ...
    |  ``attribute type:`` string

    |  ``transactional_ind:`` Flag indicating if devices should be reserved during execution of this script.
    |  ``attribute type:`` bool

    """

    properties = ("id",
                  "name",
                  "module",
                  "visible",
                  "description",
                  "created_by",
                  "updated_by",
                  "language",
                  "risk_level",
                  "created_at",
                  "updated_at",
                  "category",
                  "read_only",
                  "taskflow_create",
                  "taskflow_edit",
                  "taskflow_revert",
                  "target_mapping",
                  "transactional_ind",
                  )
